# libhomeseer

## Python3 async library for interacting with HomeSeer HS3 and HS4 via JSON and ASCII

*Requirements:* python3, asyncio, aiohttp  
*Deprecates*: pyhs3

Install libhomeseer with `python3 -m pip install libhomeseer`.

See `example.py` in the GitHub repo for basic usage instructions.

Provides the foundation for the Home Assistant custom integration https://github.com/marthoc/homeseer.